"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const attribute_1 = require("./attribute");
const html_validate_1 = require("html-validate");
function processAttribute(attr) {
    return Array.from(attribute_1.processAttribute(attr));
}
test("should flag attributes with interpolation as dynamic", () => {
    const attrs = processAttribute({
        key: "foo",
        value: "foo{{ bar }}baz",
    });
    expect(attrs).toEqual([
        {
            key: "foo",
            value: expect.any(html_validate_1.DynamicValue),
        },
    ]);
});
test("should handle ng-attr- as target attribute", () => {
    const attrs = processAttribute({
        key: "ng-attr-foo",
        value: "bar",
    });
    expect(attrs).toEqual([
        {
            key: "ng-attr-foo",
            value: "bar",
        },
        {
            key: "foo",
            value: expect.any(html_validate_1.DynamicValue),
            originalAttribute: "ng-attr-foo",
        },
    ]);
});
test("should handle ng-required and friends as target attribute", () => {
    const attrs = processAttribute({
        key: "ng-required",
        value: "foo",
    });
    expect(attrs).toEqual([
        {
            key: "ng-required",
            value: "foo",
        },
        {
            key: "required",
            value: expect.any(html_validate_1.DynamicValue),
            originalAttribute: "ng-required",
        },
    ]);
});
test("should leave other attributes intact", () => {
    const attrs = processAttribute({
        key: "foo",
        value: "bar",
    });
    expect(attrs).toEqual([
        {
            key: "foo",
            value: "bar",
        },
    ]);
});
test("should handle boolean attributes", () => {
    const attrs = processAttribute({
        key: "foo",
        value: undefined,
    });
    expect(attrs).toEqual([
        {
            key: "foo",
            value: undefined,
        },
    ]);
});
