"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const transform_1 = require("./transform");
const attribute_1 = require("./attribute");
const parser_1 = require("html-validate/build/parser");
const config_1 = require("html-validate/build/config");
const dom_1 = require("html-validate/build/dom");
const stripIndent = require("strip-indent");
test("should extract template from components", () => {
    const result = transform_1.angularTransformJS("./test/component.js");
    expect(result).toHaveLength(1);
    expect(result[0].data).toEqual("<p>foo</i>");
    expect(result[0].filename).toEqual("./test/component.js");
    expect(result[0].line).toEqual(2);
    expect(result[0].column).toEqual(12);
});
test("should extract templates from routes", () => {
    const result = transform_1.angularTransformJS("./test/route.js");
    expect(result).toHaveLength(3);
    expect(result[0].data).toEqual("<p>foo</i>");
    expect(result[0].filename).toEqual("./test/route.js");
    expect(result[0].line).toEqual(3);
    expect(result[0].column).toEqual(31);
    expect(stripIndent(result[1].data).trim()).toEqual("<button>\n\tbar\n</button>");
    expect(result[1].filename).toEqual("./test/route.js");
    expect(result[1].line).toEqual(5);
    expect(result[1].column).toEqual(14);
    expect(stripIndent(result[2].data).trim()).toEqual('<button type="{{valid}}"></button>');
    expect(result[2].filename).toEqual("./test/route.js");
    expect(result[2].line).toEqual(12);
    expect(result[2].column).toEqual(14);
});
test("should extract template from html file", () => {
    const result = transform_1.angularTransformHTML("./test/template.html");
    expect(result).toHaveLength(1);
    expect(result[0].data).toEqual(expect.any(String));
    expect(result[0].filename).toEqual("./test/template.html");
    expect(result[0].line).toEqual(1);
    expect(result[0].column).toEqual(1);
});
test("querySelector should find class with ng-class present", () => {
    const parser = new parser_1.Parser(config_1.Config.empty());
    const source = {
        data: '<p class="foo" ng-class="bar"></p>',
        filename: "inline",
        line: 1,
        column: 1,
        hooks: {
            processAttribute: attribute_1.processAttribute,
        },
    };
    const doc = parser.parseHtml(source);
    const node = doc.querySelector(".foo");
    expect(node).toBeInstanceOf(dom_1.HtmlElement);
    expect(Array.from(node.classList)).toEqual(["foo"]);
    expect(node.getAttribute("class", true)).toEqual([
        expect.objectContaining({
            key: "class",
            value: "foo",
        }),
        expect.objectContaining({
            key: "class",
            value: expect.any(dom_1.DynamicValue),
            originalAttribute: "ng-class",
        }),
    ]);
});
